Class: Google::Apis::PagespeedonlineV5::CategoryGroupV5

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/pagespeedonline_v5/classes.rb,
lib/google/apis/pagespeedonline_v5/representations.rb,
lib/google/apis/pagespeedonline_v5/representations.rb

Overview

Message containing a category

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CategoryGroupV5

Returns a new instance of CategoryGroupV5.



164
165
166
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 164

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

The description of what the category is grouping Corresponds to the JSON property description

Returns:

  • (String)


157
158
159
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 157

def description
  @description
end

#titleString

The human readable title of the group Corresponds to the JSON property title

Returns:

  • (String)


162
163
164
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 162

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



169
170
171
172
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 169

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @title = args[:title] if args.key?(:title)
end