Class: Google::Apis::PagespeedonlineV5::LighthouseCategoryV5
- Inherits:
-
Object
- Object
- Google::Apis::PagespeedonlineV5::LighthouseCategoryV5
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/pagespeedonline_v5/classes.rb,
lib/google/apis/pagespeedonline_v5/representations.rb,
lib/google/apis/pagespeedonline_v5/representations.rb
Overview
A Lighthouse category.
Instance Attribute Summary collapse
-
#audit_refs ⇒ Array<Google::Apis::PagespeedonlineV5::AuditRefs>
An array of references to all the audit members of this category.
-
#category_score_display_mode ⇒ String
Optional.
-
#description ⇒ String
A more detailed description of the category and its importance.
-
#id ⇒ String
The string identifier of the category.
-
#manual_description ⇒ String
A description for the manual audits in the category.
-
#score ⇒ Object
The overall score of the category, the weighted average of all its audits.
-
#title ⇒ String
The human-friendly name of the category.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LighthouseCategoryV5
constructor
A new instance of LighthouseCategoryV5.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LighthouseCategoryV5
Returns a new instance of LighthouseCategoryV5.
461 462 463 |
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 461 def initialize(**args) update!(**args) end |
Instance Attribute Details
#audit_refs ⇒ Array<Google::Apis::PagespeedonlineV5::AuditRefs>
An array of references to all the audit members of this category.
Corresponds to the JSON property auditRefs
428 429 430 |
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 428 def audit_refs @audit_refs end |
#category_score_display_mode ⇒ String
Optional. How the category score should be displayed (e.g. as a fraction).
Corresponds to the JSON property categoryScoreDisplayMode
433 434 435 |
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 433 def category_score_display_mode @category_score_display_mode end |
#description ⇒ String
A more detailed description of the category and its importance.
Corresponds to the JSON property description
438 439 440 |
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 438 def description @description end |
#id ⇒ String
The string identifier of the category.
Corresponds to the JSON property id
443 444 445 |
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 443 def id @id end |
#manual_description ⇒ String
A description for the manual audits in the category.
Corresponds to the JSON property manualDescription
448 449 450 |
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 448 def manual_description @manual_description end |
#score ⇒ Object
The overall score of the category, the weighted average of all its audits. (
The category's score, can be null.)
Corresponds to the JSON property score
454 455 456 |
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 454 def score @score end |
#title ⇒ String
The human-friendly name of the category.
Corresponds to the JSON property title
459 460 461 |
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 459 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
466 467 468 469 470 471 472 473 474 |
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 466 def update!(**args) @audit_refs = args[:audit_refs] if args.key?(:audit_refs) @category_score_display_mode = args[:category_score_display_mode] if args.key?(:category_score_display_mode) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @manual_description = args[:manual_description] if args.key?(:manual_description) @score = args[:score] if args.key?(:score) @title = args[:title] if args.key?(:title) end |