Class: Google::Apis::PagespeedonlineV5::PagespeedApiLoadingExperienceV5

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/pagespeedonline_v5/classes.rb,
lib/google/apis/pagespeedonline_v5/representations.rb,
lib/google/apis/pagespeedonline_v5/representations.rb

Overview

The CrUX loading experience object that contains CrUX data breakdowns.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PagespeedApiLoadingExperienceV5

Returns a new instance of PagespeedApiLoadingExperienceV5.



683
684
685
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 683

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

The url, pattern or origin which the metrics are on. Corresponds to the JSON property id

Returns:

  • (String)


660
661
662
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 660

def id
  @id
end

#initial_urlString

The requested URL, which may differ from the resolved "id". Corresponds to the JSON property initial_url

Returns:

  • (String)


665
666
667
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 665

def initial_url
  @initial_url
end

#metricsHash<String,Google::Apis::PagespeedonlineV5::UserPageLoadMetricV5>

The map of . Corresponds to the JSON property metrics



670
671
672
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 670

def metrics
  @metrics
end

#origin_fallbackBoolean Also known as: origin_fallback?

True if the result is an origin fallback from a page, false otherwise. Corresponds to the JSON property origin_fallback

Returns:

  • (Boolean)


675
676
677
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 675

def origin_fallback
  @origin_fallback
end

#overall_categoryString

The human readable speed "category" of the id. Corresponds to the JSON property overall_category

Returns:

  • (String)


681
682
683
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 681

def overall_category
  @overall_category
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



688
689
690
691
692
693
694
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 688

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @initial_url = args[:initial_url] if args.key?(:initial_url)
  @metrics = args[:metrics] if args.key?(:metrics)
  @origin_fallback = args[:origin_fallback] if args.key?(:origin_fallback)
  @overall_category = args[:overall_category] if args.key?(:overall_category)
end