Class: Google::Apis::PagespeedonlineV5::PagespeedApiPagespeedResponseV5
- Inherits:
-
Object
- Object
- Google::Apis::PagespeedonlineV5::PagespeedApiPagespeedResponseV5
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/pagespeedonline_v5/classes.rb,
lib/google/apis/pagespeedonline_v5/representations.rb,
lib/google/apis/pagespeedonline_v5/representations.rb
Overview
The Pagespeed API response object.
Instance Attribute Summary collapse
-
#analysis_utc_timestamp ⇒ String
The UTC timestamp of this analysis.
-
#captcha_result ⇒ String
The captcha verify result Corresponds to the JSON property
captchaResult. -
#id ⇒ String
Canonicalized and final URL for the document, after following page redirects ( if any).
-
#kind ⇒ String
Kind of result.
-
#lighthouse_result ⇒ Google::Apis::PagespeedonlineV5::LighthouseResultV5
The Lighthouse result object.
-
#loading_experience ⇒ Google::Apis::PagespeedonlineV5::PagespeedApiLoadingExperienceV5
The CrUX loading experience object that contains CrUX data breakdowns.
-
#origin_loading_experience ⇒ Google::Apis::PagespeedonlineV5::PagespeedApiLoadingExperienceV5
The CrUX loading experience object that contains CrUX data breakdowns.
-
#version ⇒ Google::Apis::PagespeedonlineV5::PagespeedVersion
The Pagespeed Version object.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PagespeedApiPagespeedResponseV5
constructor
A new instance of PagespeedApiPagespeedResponseV5.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PagespeedApiPagespeedResponseV5
Returns a new instance of PagespeedApiPagespeedResponseV5.
736 737 738 |
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 736 def initialize(**args) update!(**args) end |
Instance Attribute Details
#analysis_utc_timestamp ⇒ String
The UTC timestamp of this analysis.
Corresponds to the JSON property analysisUTCTimestamp
698 699 700 |
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 698 def @analysis_utc_timestamp end |
#captcha_result ⇒ String
The captcha verify result
Corresponds to the JSON property captchaResult
703 704 705 |
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 703 def captcha_result @captcha_result end |
#id ⇒ String
Canonicalized and final URL for the document, after following page redirects (
if any).
Corresponds to the JSON property id
709 710 711 |
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 709 def id @id end |
#kind ⇒ String
Kind of result.
Corresponds to the JSON property kind
714 715 716 |
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 714 def kind @kind end |
#lighthouse_result ⇒ Google::Apis::PagespeedonlineV5::LighthouseResultV5
The Lighthouse result object.
Corresponds to the JSON property lighthouseResult
719 720 721 |
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 719 def lighthouse_result @lighthouse_result end |
#loading_experience ⇒ Google::Apis::PagespeedonlineV5::PagespeedApiLoadingExperienceV5
The CrUX loading experience object that contains CrUX data breakdowns.
Corresponds to the JSON property loadingExperience
724 725 726 |
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 724 def loading_experience @loading_experience end |
#origin_loading_experience ⇒ Google::Apis::PagespeedonlineV5::PagespeedApiLoadingExperienceV5
The CrUX loading experience object that contains CrUX data breakdowns.
Corresponds to the JSON property originLoadingExperience
729 730 731 |
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 729 def origin_loading_experience @origin_loading_experience end |
#version ⇒ Google::Apis::PagespeedonlineV5::PagespeedVersion
The Pagespeed Version object.
Corresponds to the JSON property version
734 735 736 |
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 734 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
741 742 743 744 745 746 747 748 749 750 |
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 741 def update!(**args) @analysis_utc_timestamp = args[:analysis_utc_timestamp] if args.key?(:analysis_utc_timestamp) @captcha_result = args[:captcha_result] if args.key?(:captcha_result) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @lighthouse_result = args[:lighthouse_result] if args.key?(:lighthouse_result) @loading_experience = args[:loading_experience] if args.key?(:loading_experience) @origin_loading_experience = args[:origin_loading_experience] if args.key?(:origin_loading_experience) @version = args[:version] if args.key?(:version) end |