Class: Google::Apis::PagespeedonlineV5::LighthouseCategoryV5

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/pagespeedonline_v5/classes.rb,
lib/google/apis/pagespeedonline_v5/representations.rb,
lib/google/apis/pagespeedonline_v5/representations.rb

Overview

A Lighthouse category.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LighthouseCategoryV5

Returns a new instance of LighthouseCategoryV5.



456
457
458
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 456

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#audit_refsArray<Google::Apis::PagespeedonlineV5::AuditRefs>

An array of references to all the audit members of this category. Corresponds to the JSON property auditRefs



428
429
430
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 428

def audit_refs
  @audit_refs
end

#descriptionString

A more detailed description of the category and its importance. Corresponds to the JSON property description

Returns:

  • (String)


433
434
435
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 433

def description
  @description
end

#idString

The string identifier of the category. Corresponds to the JSON property id

Returns:

  • (String)


438
439
440
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 438

def id
  @id
end

#manual_descriptionString

A description for the manual audits in the category. Corresponds to the JSON property manualDescription

Returns:

  • (String)


443
444
445
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 443

def manual_description
  @manual_description
end

#scoreObject

The overall score of the category, the weighted average of all its audits. ( The category's score, can be null.) Corresponds to the JSON property score

Returns:

  • (Object)


449
450
451
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 449

def score
  @score
end

#titleString

The human-friendly name of the category. Corresponds to the JSON property title

Returns:

  • (String)


454
455
456
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 454

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



461
462
463
464
465
466
467
468
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 461

def update!(**args)
  @audit_refs = args[:audit_refs] if args.key?(:audit_refs)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @manual_description = args[:manual_description] if args.key?(:manual_description)
  @score = args[:score] if args.key?(:score)
  @title = args[:title] if args.key?(:title)
end