Class: Google::Apis::PagespeedonlineV5::RendererFormattedStrings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/pagespeedonline_v5/classes.rb,
lib/google/apis/pagespeedonline_v5/representations.rb,
lib/google/apis/pagespeedonline_v5/representations.rb

Overview

Message holding the formatted strings used in the renderer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RendererFormattedStrings

Returns a new instance of RendererFormattedStrings.



1049
1050
1051
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 1049

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#audit_group_expand_tooltipString

The tooltip text on an expandable chevron icon. Corresponds to the JSON property auditGroupExpandTooltip

Returns:

  • (String)


785
786
787
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 785

def audit_group_expand_tooltip
  @audit_group_expand_tooltip
end

Text link pointing to the Lighthouse scoring calculator. This link immediately follows a sentence stating the performance score is calculated from the perf metrics. Corresponds to the JSON property calculatorLink

Returns:

  • (String)


792
793
794
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 792

def calculator_link
  @calculator_link
end

#crc_initial_navigationString

The label for the initial request in a critical request chain. Corresponds to the JSON property crcInitialNavigation

Returns:

  • (String)


797
798
799
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 797

def crc_initial_navigation
  @crc_initial_navigation
end

#crc_longest_duration_labelString

The label for values shown in the summary of critical request chains. Corresponds to the JSON property crcLongestDurationLabel

Returns:

  • (String)


802
803
804
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 802

def crc_longest_duration_label
  @crc_longest_duration_label
end

Option in a dropdown menu that copies the Lighthouse JSON object to the system clipboard. Corresponds to the JSON property dropdownCopyJSON

Returns:

  • (String)


808
809
810
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 808

def dropdown_copy_json
  @dropdown_copy_json
end

Option in a dropdown menu that toggles the themeing of the report between Light(default) and Dark themes. Corresponds to the JSON property dropdownDarkTheme

Returns:

  • (String)


814
815
816
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 814

def dropdown_dark_theme
  @dropdown_dark_theme
end

Option in a dropdown menu that opens a full Lighthouse report in a print dialog. Corresponds to the JSON property dropdownPrintExpanded

Returns:

  • (String)


820
821
822
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 820

def dropdown_print_expanded
  @dropdown_print_expanded
end

Option in a dropdown menu that opens a small, summary report in a print dialog. Corresponds to the JSON property dropdownPrintSummary

Returns:

  • (String)


825
826
827
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 825

def dropdown_print_summary
  @dropdown_print_summary
end

Option in a dropdown menu that saves the current report as a new GitHub Gist. Corresponds to the JSON property dropdownSaveGist

Returns:

  • (String)


830
831
832
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 830

def dropdown_save_gist
  @dropdown_save_gist
end

Option in a dropdown menu that saves the Lighthouse report HTML locally to the system as a '.html' file. Corresponds to the JSON property dropdownSaveHTML

Returns:

  • (String)


836
837
838
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 836

def dropdown_save_html
  @dropdown_save_html
end

Option in a dropdown menu that saves the Lighthouse JSON object to the local system as a '.json' file. Corresponds to the JSON property dropdownSaveJSON

Returns:

  • (String)


842
843
844
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 842

def dropdown_save_json
  @dropdown_save_json
end

Option in a dropdown menu that opens the current report in the Lighthouse Viewer Application. Corresponds to the JSON property dropdownViewer

Returns:

  • (String)


848
849
850
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 848

def dropdown_viewer
  @dropdown_viewer
end

#error_labelString

The label shown next to an audit or metric that has had an error. Corresponds to the JSON property errorLabel

Returns:

  • (String)


853
854
855
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 853

def error_label
  @error_label
end

#error_missing_audit_infoString

The error string shown next to an erroring audit. Corresponds to the JSON property errorMissingAuditInfo

Returns:

  • (String)


858
859
860
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 858

def error_missing_audit_info
  @error_missing_audit_info
end

Label for button to create an issue against the Lighthouse GitHub project. Corresponds to the JSON property footerIssue

Returns:

  • (String)


863
864
865
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 863

def footer_issue
  @footer_issue
end

#lab_data_titleString

The title of the lab data performance category. Corresponds to the JSON property labDataTitle

Returns:

  • (String)


868
869
870
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 868

def lab_data_title
  @lab_data_title
end

#ls_performance_category_descriptionString

The disclaimer shown under performance explaining that the network can vary. Corresponds to the JSON property lsPerformanceCategoryDescription

Returns:

  • (String)


873
874
875
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 873

def ls_performance_category_description
  @ls_performance_category_description
end

#manual_audits_group_titleString

The heading shown above a list of audits that were not computerd in the run. Corresponds to the JSON property manualAuditsGroupTitle

Returns:

  • (String)


878
879
880
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 878

def manual_audits_group_title
  @manual_audits_group_title
end

#not_applicable_audits_group_titleString

The heading shown above a list of audits that do not apply to a page. Corresponds to the JSON property notApplicableAuditsGroupTitle

Returns:

  • (String)


883
884
885
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 883

def not_applicable_audits_group_title
  @not_applicable_audits_group_title
end

#opportunity_resource_column_labelString

The heading for the estimated page load savings opportunity of an audit. Corresponds to the JSON property opportunityResourceColumnLabel

Returns:

  • (String)


888
889
890
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 888

def opportunity_resource_column_label
  @opportunity_resource_column_label
end

#opportunity_savings_column_labelString

The heading for the estimated page load savings of opportunity audits. Corresponds to the JSON property opportunitySavingsColumnLabel

Returns:

  • (String)


893
894
895
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 893

def opportunity_savings_column_label
  @opportunity_savings_column_label
end

#passed_audits_group_titleString

The heading that is shown above a list of audits that are passing. Corresponds to the JSON property passedAuditsGroupTitle

Returns:

  • (String)


898
899
900
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 898

def passed_audits_group_title
  @passed_audits_group_title
end

#runtime_desktop_emulationString

Descriptive explanation for emulation setting when emulating a generic desktop form factor, as opposed to a mobile-device like form factor. Corresponds to the JSON property runtimeDesktopEmulation

Returns:

  • (String)


904
905
906
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 904

def runtime_desktop_emulation
  @runtime_desktop_emulation
end

#runtime_mobile_emulationString

Descriptive explanation for emulation setting when emulating a Nexus 5X mobile device. Corresponds to the JSON property runtimeMobileEmulation

Returns:

  • (String)


910
911
912
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 910

def runtime_mobile_emulation
  @runtime_mobile_emulation
end

#runtime_no_emulationString

Descriptive explanation for emulation setting when no device emulation is set. Corresponds to the JSON property runtimeNoEmulation

Returns:

  • (String)


915
916
917
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 915

def runtime_no_emulation
  @runtime_no_emulation
end

#runtime_settings_axe_versionString

Label for a row in a table that shows the version of the Axe library used Corresponds to the JSON property runtimeSettingsAxeVersion

Returns:

  • (String)


920
921
922
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 920

def runtime_settings_axe_version
  @runtime_settings_axe_version
end

#runtime_settings_benchmarkString

Label for a row in a table that shows the estimated CPU power of the machine running Lighthouse. Example row values: 532, 1492, 783. Corresponds to the JSON property runtimeSettingsBenchmark

Returns:

  • (String)


926
927
928
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 926

def runtime_settings_benchmark
  @runtime_settings_benchmark
end

#runtime_settings_channelString

Label for a row in a table that shows in what tool Lighthouse is being run (e. g. The lighthouse CLI, Chrome DevTools, Lightrider, WebPageTest, etc). Corresponds to the JSON property runtimeSettingsChannel

Returns:

  • (String)


938
939
940
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 938

def runtime_settings_channel
  @runtime_settings_channel
end

#runtime_settings_cpu_throttlingString

Label for a row in a table that describes the CPU throttling conditions that were used during a Lighthouse run, if any. Corresponds to the JSON property runtimeSettingsCPUThrottling

Returns:

  • (String)


932
933
934
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 932

def runtime_settings_cpu_throttling
  @runtime_settings_cpu_throttling
end

#runtime_settings_deviceString

Label for a row in a table that describes the kind of device that was emulated for the Lighthouse run. Example values for row elements: 'No Emulation', ' Emulated Desktop', etc. Corresponds to the JSON property runtimeSettingsDevice

Returns:

  • (String)


945
946
947
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 945

def runtime_settings_device
  @runtime_settings_device
end

#runtime_settings_fetch_timeString

Label for a row in a table that shows the time at which a Lighthouse run was conducted; formatted as a timestamp, e.g. Jan 1, 1970 12:00 AM UTC. Corresponds to the JSON property runtimeSettingsFetchTime

Returns:

  • (String)


951
952
953
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 951

def runtime_settings_fetch_time
  @runtime_settings_fetch_time
end

#runtime_settings_network_throttlingString

Label for a row in a table that describes the network throttling conditions that were used during a Lighthouse run, if any. Corresponds to the JSON property runtimeSettingsNetworkThrottling

Returns:

  • (String)


957
958
959
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 957

def runtime_settings_network_throttling
  @runtime_settings_network_throttling
end

#runtime_settings_titleString

Title of the Runtime settings table in a Lighthouse report. Runtime settings are the environment configurations that a specific report used at auditing time. Corresponds to the JSON property runtimeSettingsTitle

Returns:

  • (String)


964
965
966
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 964

def runtime_settings_title
  @runtime_settings_title
end

#runtime_settings_uaString

Label for a row in a table that shows the User Agent that was detected on the Host machine that ran Lighthouse. Corresponds to the JSON property runtimeSettingsUA

Returns:

  • (String)


970
971
972
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 970

def runtime_settings_ua
  @runtime_settings_ua
end

#runtime_settings_ua_networkString

Label for a row in a table that shows the User Agent that was used to send out all network requests during the Lighthouse run. Corresponds to the JSON property runtimeSettingsUANetwork

Returns:

  • (String)


976
977
978
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 976

def runtime_settings_ua_network
  @runtime_settings_ua_network
end

#runtime_settings_urlString

Label for a row in a table that shows the URL that was audited during a Lighthouse run. Corresponds to the JSON property runtimeSettingsUrl

Returns:

  • (String)


982
983
984
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 982

def runtime_settings_url
  @runtime_settings_url
end

#runtime_unknownString

Descriptive explanation for a runtime setting that is set to an unknown value. Corresponds to the JSON property runtimeUnknown

Returns:

  • (String)


987
988
989
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 987

def runtime_unknown
  @runtime_unknown
end

#scorescale_labelString

The label that explains the score gauges scale (0-49, 50-89, 90-100). Corresponds to the JSON property scorescaleLabel

Returns:

  • (String)


992
993
994
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 992

def scorescale_label
  @scorescale_label
end

#show_relevant_auditsString

Label preceding a radio control for filtering the list of audits. The radio choices are various performance metrics (FCP, LCP, TBT), and if chosen, the audits in the report are hidden if they are not relevant to the selected metric. Corresponds to the JSON property showRelevantAudits

Returns:

  • (String)


1000
1001
1002
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 1000

def show_relevant_audits
  @show_relevant_audits
end

#snippet_collapse_button_labelString

The label for the button to show only a few lines of a snippet Corresponds to the JSON property snippetCollapseButtonLabel

Returns:

  • (String)


1005
1006
1007
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 1005

def snippet_collapse_button_label
  @snippet_collapse_button_label
end

#snippet_expand_button_labelString

The label for the button to show all lines of a snippet Corresponds to the JSON property snippetExpandButtonLabel

Returns:

  • (String)


1010
1011
1012
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 1010

def snippet_expand_button_label
  @snippet_expand_button_label
end

#third_party_resources_labelString

This label is for a filter checkbox above a table of items Corresponds to the JSON property thirdPartyResourcesLabel

Returns:

  • (String)


1015
1016
1017
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 1015

def third_party_resources_label
  @third_party_resources_label
end

#throttling_providedString

Descriptive explanation for environment throttling that was provided by the runtime environment instead of provided by Lighthouse throttling. Corresponds to the JSON property throttlingProvided

Returns:

  • (String)


1021
1022
1023
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 1021

def throttling_provided
  @throttling_provided
end

#toplevel_warnings_messageString

The label shown preceding important warnings that may have invalidated an entire report. Corresponds to the JSON property toplevelWarningsMessage

Returns:

  • (String)


1027
1028
1029
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 1027

def toplevel_warnings_message
  @toplevel_warnings_message
end

#variance_disclaimerString

The disclaimer shown below a performance metric value. Corresponds to the JSON property varianceDisclaimer

Returns:

  • (String)


1032
1033
1034
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 1032

def variance_disclaimer
  @variance_disclaimer
end

#view_treemap_labelString

Label for a button that opens the Treemap App Corresponds to the JSON property viewTreemapLabel

Returns:

  • (String)


1037
1038
1039
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 1037

def view_treemap_label
  @view_treemap_label
end

#warning_audits_group_titleString

The heading that is shown above a list of audits that have warnings Corresponds to the JSON property warningAuditsGroupTitle

Returns:

  • (String)


1042
1043
1044
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 1042

def warning_audits_group_title
  @warning_audits_group_title
end

#warning_headerString

The label shown above a bulleted list of warnings. Corresponds to the JSON property warningHeader

Returns:

  • (String)


1047
1048
1049
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 1047

def warning_header
  @warning_header
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
1082
1083
1084
1085
1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
1097
1098
1099
1100
1101
1102
1103
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 1054

def update!(**args)
  @audit_group_expand_tooltip = args[:audit_group_expand_tooltip] if args.key?(:audit_group_expand_tooltip)
  @calculator_link = args[:calculator_link] if args.key?(:calculator_link)
  @crc_initial_navigation = args[:crc_initial_navigation] if args.key?(:crc_initial_navigation)
  @crc_longest_duration_label = args[:crc_longest_duration_label] if args.key?(:crc_longest_duration_label)
  @dropdown_copy_json = args[:dropdown_copy_json] if args.key?(:dropdown_copy_json)
  @dropdown_dark_theme = args[:dropdown_dark_theme] if args.key?(:dropdown_dark_theme)
  @dropdown_print_expanded = args[:dropdown_print_expanded] if args.key?(:dropdown_print_expanded)
  @dropdown_print_summary = args[:dropdown_print_summary] if args.key?(:dropdown_print_summary)
  @dropdown_save_gist = args[:dropdown_save_gist] if args.key?(:dropdown_save_gist)
  @dropdown_save_html = args[:dropdown_save_html] if args.key?(:dropdown_save_html)
  @dropdown_save_json = args[:dropdown_save_json] if args.key?(:dropdown_save_json)
  @dropdown_viewer = args[:dropdown_viewer] if args.key?(:dropdown_viewer)
  @error_label = args[:error_label] if args.key?(:error_label)
  @error_missing_audit_info = args[:error_missing_audit_info] if args.key?(:error_missing_audit_info)
  @footer_issue = args[:footer_issue] if args.key?(:footer_issue)
  @lab_data_title = args[:lab_data_title] if args.key?(:lab_data_title)
  @ls_performance_category_description = args[:ls_performance_category_description] if args.key?(:ls_performance_category_description)
  @manual_audits_group_title = args[:manual_audits_group_title] if args.key?(:manual_audits_group_title)
  @not_applicable_audits_group_title = args[:not_applicable_audits_group_title] if args.key?(:not_applicable_audits_group_title)
  @opportunity_resource_column_label = args[:opportunity_resource_column_label] if args.key?(:opportunity_resource_column_label)
  @opportunity_savings_column_label = args[:opportunity_savings_column_label] if args.key?(:opportunity_savings_column_label)
  @passed_audits_group_title = args[:passed_audits_group_title] if args.key?(:passed_audits_group_title)
  @runtime_desktop_emulation = args[:runtime_desktop_emulation] if args.key?(:runtime_desktop_emulation)
  @runtime_mobile_emulation = args[:runtime_mobile_emulation] if args.key?(:runtime_mobile_emulation)
  @runtime_no_emulation = args[:runtime_no_emulation] if args.key?(:runtime_no_emulation)
  @runtime_settings_axe_version = args[:runtime_settings_axe_version] if args.key?(:runtime_settings_axe_version)
  @runtime_settings_benchmark = args[:runtime_settings_benchmark] if args.key?(:runtime_settings_benchmark)
  @runtime_settings_cpu_throttling = args[:runtime_settings_cpu_throttling] if args.key?(:runtime_settings_cpu_throttling)
  @runtime_settings_channel = args[:runtime_settings_channel] if args.key?(:runtime_settings_channel)
  @runtime_settings_device = args[:runtime_settings_device] if args.key?(:runtime_settings_device)
  @runtime_settings_fetch_time = args[:runtime_settings_fetch_time] if args.key?(:runtime_settings_fetch_time)
  @runtime_settings_network_throttling = args[:runtime_settings_network_throttling] if args.key?(:runtime_settings_network_throttling)
  @runtime_settings_title = args[:runtime_settings_title] if args.key?(:runtime_settings_title)
  @runtime_settings_ua = args[:runtime_settings_ua] if args.key?(:runtime_settings_ua)
  @runtime_settings_ua_network = args[:runtime_settings_ua_network] if args.key?(:runtime_settings_ua_network)
  @runtime_settings_url = args[:runtime_settings_url] if args.key?(:runtime_settings_url)
  @runtime_unknown = args[:runtime_unknown] if args.key?(:runtime_unknown)
  @scorescale_label = args[:scorescale_label] if args.key?(:scorescale_label)
  @show_relevant_audits = args[:show_relevant_audits] if args.key?(:show_relevant_audits)
  @snippet_collapse_button_label = args[:snippet_collapse_button_label] if args.key?(:snippet_collapse_button_label)
  @snippet_expand_button_label = args[:snippet_expand_button_label] if args.key?(:snippet_expand_button_label)
  @third_party_resources_label = args[:third_party_resources_label] if args.key?(:third_party_resources_label)
  @throttling_provided = args[:throttling_provided] if args.key?(:throttling_provided)
  @toplevel_warnings_message = args[:toplevel_warnings_message] if args.key?(:toplevel_warnings_message)
  @variance_disclaimer = args[:variance_disclaimer] if args.key?(:variance_disclaimer)
  @view_treemap_label = args[:view_treemap_label] if args.key?(:view_treemap_label)
  @warning_audits_group_title = args[:warning_audits_group_title] if args.key?(:warning_audits_group_title)
  @warning_header = args[:warning_header] if args.key?(:warning_header)
end