Class: Google::Apis::PagespeedonlineV5::UserPageLoadMetricV5
- Inherits:
-
Object
- Object
- Google::Apis::PagespeedonlineV5::UserPageLoadMetricV5
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/pagespeedonline_v5/classes.rb,
lib/google/apis/pagespeedonline_v5/representations.rb,
lib/google/apis/pagespeedonline_v5/representations.rb
Overview
A CrUX metric object for a single metric and form factor.
Instance Attribute Summary collapse
-
#category ⇒ String
The category of the specific time metric.
-
#distributions ⇒ Array<Google::Apis::PagespeedonlineV5::Bucket>
Metric distributions.
-
#form_factor ⇒ String
Identifies the form factor of the metric being collected.
-
#median ⇒ Fixnum
The median number of the metric, in millisecond.
-
#metric_id ⇒ String
Identifies the type of the metric.
-
#percentile ⇒ Fixnum
We use this field to store certain percentile value for this metric.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UserPageLoadMetricV5
constructor
A new instance of UserPageLoadMetricV5.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UserPageLoadMetricV5
Returns a new instance of UserPageLoadMetricV5.
1228 1229 1230 |
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 1228 def initialize(**args) update!(**args) end |
Instance Attribute Details
#category ⇒ String
The category of the specific time metric.
Corresponds to the JSON property category
1200 1201 1202 |
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 1200 def category @category end |
#distributions ⇒ Array<Google::Apis::PagespeedonlineV5::Bucket>
Metric distributions. Proportions should sum up to 1.
Corresponds to the JSON property distributions
1205 1206 1207 |
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 1205 def distributions @distributions end |
#form_factor ⇒ String
Identifies the form factor of the metric being collected.
Corresponds to the JSON property formFactor
1210 1211 1212 |
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 1210 def form_factor @form_factor end |
#median ⇒ Fixnum
The median number of the metric, in millisecond.
Corresponds to the JSON property median
1215 1216 1217 |
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 1215 def median @median end |
#metric_id ⇒ String
Identifies the type of the metric.
Corresponds to the JSON property metricId
1220 1221 1222 |
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 1220 def metric_id @metric_id end |
#percentile ⇒ Fixnum
We use this field to store certain percentile value for this metric. For v4,
this field contains pc50. For v5, this field contains pc90.
Corresponds to the JSON property percentile
1226 1227 1228 |
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 1226 def percentile @percentile end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1233 1234 1235 1236 1237 1238 1239 1240 |
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 1233 def update!(**args) @category = args[:category] if args.key?(:category) @distributions = args[:distributions] if args.key?(:distributions) @form_factor = args[:form_factor] if args.key?(:form_factor) @median = args[:median] if args.key?(:median) @metric_id = args[:metric_id] if args.key?(:metric_id) @percentile = args[:percentile] if args.key?(:percentile) end |