Class: Google::Apis::PagespeedonlineV5::UserPageLoadMetricV5

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/pagespeedonline_v5/classes.rb,
lib/google/apis/pagespeedonline_v5/representations.rb,
lib/google/apis/pagespeedonline_v5/representations.rb

Overview

A CrUX metric object for a single metric and form factor.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UserPageLoadMetricV5

Returns a new instance of UserPageLoadMetricV5.



1222
1223
1224
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 1222

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#categoryString

The category of the specific time metric. Corresponds to the JSON property category

Returns:

  • (String)


1194
1195
1196
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 1194

def category
  @category
end

#distributionsArray<Google::Apis::PagespeedonlineV5::Bucket>

Metric distributions. Proportions should sum up to 1. Corresponds to the JSON property distributions



1199
1200
1201
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 1199

def distributions
  @distributions
end

#form_factorString

Identifies the form factor of the metric being collected. Corresponds to the JSON property formFactor

Returns:

  • (String)


1204
1205
1206
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 1204

def form_factor
  @form_factor
end

#medianFixnum

The median number of the metric, in millisecond. Corresponds to the JSON property median

Returns:

  • (Fixnum)


1209
1210
1211
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 1209

def median
  @median
end

#metric_idString

Identifies the type of the metric. Corresponds to the JSON property metricId

Returns:

  • (String)


1214
1215
1216
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 1214

def metric_id
  @metric_id
end

#percentileFixnum

We use this field to store certain percentile value for this metric. For v4, this field contains pc50. For v5, this field contains pc90. Corresponds to the JSON property percentile

Returns:

  • (Fixnum)


1220
1221
1222
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 1220

def percentile
  @percentile
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1227
1228
1229
1230
1231
1232
1233
1234
# File 'lib/google/apis/pagespeedonline_v5/classes.rb', line 1227

def update!(**args)
  @category = args[:category] if args.key?(:category)
  @distributions = args[:distributions] if args.key?(:distributions)
  @form_factor = args[:form_factor] if args.key?(:form_factor)
  @median = args[:median] if args.key?(:median)
  @metric_id = args[:metric_id] if args.key?(:metric_id)
  @percentile = args[:percentile] if args.key?(:percentile)
end